<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */

if ( ! function_exists( 'educollege_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Educollege Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function educollege_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'educollege_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'educollege_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Educollege Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function educollege_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'educollege_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'educollege_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Educollege Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function educollege_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'educollege_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'educollege_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Educollege Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function educollege_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_slider_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	$slider_enable = $control->manager->get_setting( 'educollege_pro_theme_options[slider_section_enable]' )->value() ;

	if(in_array($control->id, array(
		'educollege_pro_theme_options[course_form]',
	))) return ($slider_enable && $home_layout == 'default-design');

	return ( $slider_enable );
}

/**
 * Check if slider section content type is category.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[slider_content_type]' )->value();
	return educollege_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[slider_content_type]' )->value();
	return educollege_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[slider_content_type]' )->value();
	return educollege_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if Featured section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_featured_section_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return (in_array($home_layout,array('third-design','fifth-design')));
}
/**
 * Check if Featured section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_featured_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[featured_section_enable]' )->value() && in_array($home_layout,array('third-design','fifth-design')));
}

/**
 * Check if featured section content type is category.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[featured_content_type]' )->value();
	return educollege_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if featured section content type is category.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_featured_medical_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return educollege_pro_is_featured_section_enable( $control ) && ( 'fifth-design' == $home_layout );
}

/**
 * Check if featured section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[featured_content_type]' )->value();
	return educollege_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[featured_content_type]' )->value();
	return educollege_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_service_section_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $home_layout != 'third-design' );
}

/**
 * Check if service section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_service_section_enable( $control ) {
	$service_count = $control->manager->get_setting( 'educollege_pro_theme_options[service_count]' )->value();
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	if($home_layout == 'fifth-design'){
		for($i = 1 ; $i<= $service_count; $i++){
			if(in_array($control->id, array('educollege_pro_theme_options[service_content_icon_' . $i . ']','educollege_pro_theme_options[service_title]', 'educollege_pro_theme_options[service_sub_title]'))) return false;
		}
	}
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is category.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[service_content_type]' )->value();
	return educollege_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[service_content_type]' )->value();
	return educollege_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[service_content_type]' )->value();
	return educollege_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_about_section_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $home_layout != 'third-design' );
}

/**
 * Check if about section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is custom.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[about_content_type]' )->value();
	return educollege_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[about_content_type]' )->value();
	return educollege_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[about_content_type]' )->value();
	return educollege_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if reason panel section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_reason_section_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( ($home_layout == 'fifth-design') );
}

/**
 * Check if reason section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_reason_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[reason_section_enable]' )->value() && ($home_layout == 'fifth-design') );
}

/**
 * Check if reason section content type is custom.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_reason_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[reason_content_type]' )->value();
	return educollege_pro_is_reason_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if reason section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_reason_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[reason_content_type]' )->value();
	return educollege_pro_is_reason_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reason section content type is post.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_reason_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[reason_content_type]' )->value();
	return educollege_pro_is_reason_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_course_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	if($control->id == 'educollege_pro_course_section'){
		return (in_array($home_layout, array('default-design','fourth-design')));
	}
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[course_section_enable]' )->value() && ! in_array($home_layout,array('third-design','fifth-design')));
}

/**
 * Check if course section content type is post.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[course_content_type]' )->value();
	return educollege_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section seperator.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_course_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[course_content_type]' )->value();
	return educollege_pro_is_course_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if course section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[course_content_type]' )->value();
	return educollege_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[course_content_type]' )->value();
	return educollege_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_course_section_content_course_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[course_content_type]' )->value();
	return educollege_pro_is_course_section_enable( $control ) && ( 'course' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_course_section_content_course_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[course_content_type]' )->value();
	return educollege_pro_is_course_section_enable( $control ) && ( 'course-category' == $content_type );
}

/**
 * Check if cta section panel is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_cta_section_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[cta_section_enable]' )->value() && ! in_array($home_layout,array('third-design','fifth-design')));
}

/**
 * Check if cta section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_cta_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[cta_section_enable]' )->value() && ! in_array($home_layout,array('third-design','fifth-design')));
}

/**
 * Check if cta section content type is post.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[cta_content_type]' )->value();
	return educollege_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[cta_content_type]' )->value();
	return educollege_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[cta_content_type]' )->value();
	return educollege_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_team_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();

	if($control->id == 'educollege_pro_team_section'){
		return ( $home_layout == 'default-design' );
	}
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[team_section_enable]' )->value() && ! in_array($home_layout,array('third-design','fifth-design')));
}

/**
 * Check if team section content type is post.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[team_content_type]' )->value();
	return educollege_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section seperator.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[team_content_type]' )->value();
	return educollege_pro_is_team_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[team_content_type]' )->value();
	return educollege_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[team_content_type]' )->value();
	return educollege_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_team_section_content_team_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[team_content_type]' )->value();
	return educollege_pro_is_team_section_enable( $control ) && ( 'tp-team' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_team_section_content_team_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[team_content_type]' )->value();
	return educollege_pro_is_team_section_enable( $control ) && ( 'tp-team-category' == $content_type );
}

/**
 * Check if counter section is enabled.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_counter_section_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( ! in_array($home_layout,array('third-design','fifth-design')));
}

/**
 * Check if counter section is enabled.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_counter_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[counter_section_enable]' )->value() && ! in_array($home_layout,array('third-design','fifth-design')));
}

/**
 * Check if client section is enabled.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_client_section_panel_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $home_layout != 'third-design');
}
/**
 * Check if client section is enabled.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_client_section_enable( $control ) {
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[client_section_enable]' )->value() );
}

/**
 * Check if client section content type is category.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_client_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[client_content_type]' )->value();
	return educollege_pro_is_client_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if client section content type is page.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_client_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[client_content_type]' )->value();
	return educollege_pro_is_client_section_enable( $control ) && ( 'page' == $content_type );
}

/*
 * Check if client section content type is post.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
 
function educollege_pro_is_client_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[client_content_type]' )->value();
	return educollege_pro_is_client_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if client section content type is recent.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_client_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[client_content_type]' )->value();
	return educollege_pro_is_client_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_blog_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	if(($control->id == 'educollege_pro_theme_options[blog_title]') && ($home_layout == 'third-design')) return false;
	if(($control->id == 'educollege_pro_theme_options[blog_description]') && ($home_layout != 'fifth-design')) return false;
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_type]' )->value();
	return educollege_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_type]' )->value();
	return educollege_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_type]' )->value();
	return educollege_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_type]' )->value();
	return educollege_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_blog_btn_url_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return (educollege_pro_is_blog_section_enable( $control ) && ! in_array($home_layout,array('third-design','fifth-design')));
}

// blog section event callbacks

function educollege_pro_is_blog_design_disable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ($home_layout != 'third-design' );
}

function educollege_pro_is_blog_section_event_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[blog_event_enable]' )->value() && ! in_array($home_layout,array('third-design','fifth-design')));
}

function educollege_pro_is_blog_section_content_post_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_event_type]' )->value();
	return educollege_pro_is_blog_section_event_enable( $control ) && ( 'post' == $content_type );
}

function educollege_pro_is_blog_section_content_page_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_event_type]' )->value();
	return educollege_pro_is_blog_section_event_enable( $control ) && ( 'page' == $content_type );
}

function educollege_pro_is_blog_section_content_category_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_event_type]' )->value();
	return educollege_pro_is_blog_section_event_enable( $control ) && ( 'category' == $content_type );
}

function educollege_pro_is_blog_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_event_type]' )->value();
	return educollege_pro_is_blog_section_event_enable( $control ) && ( 'event' == $content_type );
}

function educollege_pro_is_blog_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[blog_content_event_type]' )->value();
	return educollege_pro_is_blog_section_event_enable( $control ) && ( 'event-category' == $content_type );
}


/**
 * Check if testimonial section is enabled.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_testimonial_section_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();

	if($control->id == 'educollege_pro_testimonial_section'){
		return ( ! in_array($home_layout,array('third-design','fifth-design')));
	}elseif( in_array( $control->id, array(
		'educollege_pro_theme_options[testimonial_logo]',
		'educollege_pro_theme_options[testimonial_btn_title]',
		'educollege_pro_theme_options[testimonial_btn_url]'
		))) return ($control->manager->get_setting( 'educollege_pro_theme_options[testimonial_section_enable]' )->value() && $home_layout == 'default-design');
	
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_section_enable]' )->value() && ! in_array($home_layout,array('third-design','fifth-design')));
}

/**
 * Check if testimonial section seperator.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_content_type]' )->value();
	return educollege_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_content_type]' )->value();
	return educollege_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_content_type]' )->value();
	return educollege_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_content_type]' )->value();
	return educollege_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_content_type]' )->value();
	return educollege_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type && 'tp-testimonial' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_content_type]' )->value();
	return educollege_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since educollege Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function educollege_pro_is_testimonial_section_content_testimonial_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_content_type]' )->value();
	return educollege_pro_is_testimonial_section_enable( $control ) && ( 'tp-testimonial' == $content_type  );
}

function educollege_pro_is_testimonial_section_link_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'educollege_pro_theme_options[home_layout]' )->value();

	if($control->id == 'educollege_pro_theme_options[testimonial_section_link_enable]'){
		return (educollege_pro_is_testimonial_section_enable($control) && $home_layout == 'default-design');
	}
	return ( $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_section_link_enable]' )->value() && $home_layout == 'default-design' && educollege_pro_is_testimonial_section_enable($control));
}

function educollege_pro_is_testimonial_section_link_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_link_content_type]' )->value();
	return educollege_pro_is_testimonial_section_link_enable( $control ) && ( 'post' == $content_type );
}

function educollege_pro_is_testimonial_section_link_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_link_content_type]' )->value();
	return educollege_pro_is_testimonial_section_link_enable( $control ) && ( 'page' == $content_type );
}

function educollege_pro_is_testimonial_section_link_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'educollege_pro_theme_options[testimonial_link_content_type]' )->value();
	return educollege_pro_is_testimonial_section_link_enable( $control ) && ( 'custom' == $content_type );
}






