<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 * @return array An array of default values
 */

function educollege_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$educollege_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#2c2d39',
		'header_tagline_color'			=> '#990f12',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#990f12',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'educollege-pro' ), '[the-year]', '[site-link]' ),
		'footer_social_enable'			=> true,
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,featured,service,about,course,reason,cta,team,blog,counter,testimonial,client',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'educollege-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		'nav_search_enable'				=> true,

		// topbar
		'topbar_section_enable'			=> true,
		'social_menu_enable'			=> true,
		'topbar_btn_title'				=> esc_html__( 'Apply', 'educollege-pro' ),
		'topbar_btn_url'				=> esc_html__( '#', 'educollege-pro' ),
		'topbar_field_1'				=> esc_html__( ' 123 456 7891', 'educollege-pro' ),
		'topbar_field_2'				=> esc_html__( 'info@educollege.com', 'educollege-pro' ),
		
		// slider search
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'page',
		'slider_autoplay'				=> false,
		'slider_count'					=> 3,
		'slider_title'					=> esc_html__( 'Are you ready to join', 'educollege-pro' ),
		'slider_btn_label'				=> esc_html__( 'Learn More', 'educollege-pro' ),
		'slider_alt_btn_label'			=> esc_html__( 'Apply Now', 'educollege-pro' ),
		'course_form'					=> false,
		
		//featured
		'featured_section_enable'		=> true,
		'featured_count'				=> 3,
		'featured_title'					=> esc_html__( 'Our Features', 'educollege-pro' ),
		'featured_content_type'			=> 'post',
		'featured_content_icon'			=> esc_attr( 'fa-graduation-cap' ),


		//service 
		'service_section_enable'		=> true,
		'service_content_type'			=> 'page',
		'service_title'					=> esc_html__( 'Welcome To Educollege', 'educollege-pro' ),
		'service_sub_title'				=> esc_html__( 'College is a time where you want to figure out what you are going to do with your life. At the beginning of major, your idea of career is hypothetical.', 'educollege-pro' ),
		'service_count'					=> 3,
		'service_column_layout'			=> 'col-3',
		'service_content_icon_1'		=> esc_attr( 'fa-mortar-board'),
		'service_content_icon_2'		=> esc_attr( 'fa-user'),
		'service_content_icon_3'		=> esc_attr( 'fa-book'),

		//about 
		'about_section_enable'		=> true,
		'about_content_type'		=> 'page',
		'about_title'				=> esc_html__( 'About Us', 'educollege-pro' ),
		'about_description'			=> esc_html__( 'Get know about us', 'educollege-pro' ),
		'about_btn_title'			=> esc_html__( 'Learn More', 'educollege-pro' ),
		
		//reason
		'reason_section_enable'		=> true,
		'reason_content_type'		=> 'custom',
		'reason_title'				=> esc_html__( 'About Us', 'educollege-pro' ),
		'reason_description'		=> esc_html__( 'College is a time where you want to figure out what you are going to do with your life. At the beginning of major, your idea of career is hypothetical.', 'educollege-pro' ),
		'reason_btn_title'			=> esc_html__( 'Learn More', 'educollege-pro' ),

		//course 
		'course_section_enable'		=> true,
		'course_content_type'		=> 'page',
		'course_count'				=> 4,
		'course_read_more'			=> esc_html__( 'Learn More', 'educollege-pro' ),
		'course_title'				=> esc_html__( 'Our Featured Courses', 'educollege-pro' ),
		'course_sub_title'			=> esc_html__( 'College is a time where you want to figure out what you are going to do with your life. At the beginning of major, your idea of career is hypothetical.', 'educollege-pro' ),
		'course_btn_title'			=> esc_html__( 'View All Courses', 'educollege-pro' ),

		//cta 
		'cta_section_enable'		=> true,
		'cta_content_type'			=> 'custom',
		'cta_title'					=> esc_html__( 'Video Tour of Educollege', 'educollege-pro' ),
		'cta_content'				=> esc_html__( 'College is a time where you want to figure out what you are going to do with your life. At the beginning of major, your idea of career is hypothetical.', 'educollege-pro' ),
		'cta_image'					=> get_template_directory_uri() . '/assets/uploads/call-to-action.jpg',

		//team 
		'team_section_enable'					=> true,
		'team_content_type'						=> 'page',
		'team_count'							=> 10,
		'team_section_autoplay_slider_enable'	=> true,
		'team_section_buttom_slider_enable'		=> true,
		'team_title'							=> esc_html__( 'Our Skilled Teachers', 'educollege-pro' ),
		'team_sub_title'						=> esc_html__( 'College is a time where you want to figure out what you are going to do with your life. At the beginning of major, your idea of career is hypothetical.', 'educollege-pro' ),			
		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'page',
		'blog_event_enable'				=> false,
		'blog_count'					=> 3,
		'blog_title'					=> esc_html__( 'Latest News', 'educollege-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Articles', 'educollege-pro' ),
		'blog_event_title'				=> esc_html__( 'Upcoming Events', 'educollege-pro' ),
		'blog_event_btn_title'			=> esc_html__( 'View All Events', 'educollege-pro' ),
		'blog_event_count'				=> 3,
		'blog_content_event_type'		=> 'page',
		
		
		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',
		'counter_content_icon_1'		=> esc_html__( 'fa-user', 'educollege-pro' ),
		'counter_title_1'				=> esc_html__( 'Students', 'educollege-pro' ),
		'counter_number_1'				=> esc_html__( '1500+', 'educollege-pro' ),
		'counter_content_icon_2'		=> esc_html__( 'fa-book', 'educollege-pro' ),
		'counter_title_2'				=> esc_html__( 'All Courses', 'educollege-pro' ),
		'counter_number_2'				=> esc_html__( '50', 'educollege-pro' ),
		'counter_content_icon_3'		=> esc_html__( 'fa-users', 'educollege-pro' ),
		'counter_title_3'				=> esc_html__( 'Certified teacher', 'educollege-pro' ),
		'counter_number_3'				=> esc_html__( '150', 'educollege-pro' ),
		'counter_content_icon_4'		=> esc_html__( 'fa-trophy', 'educollege-pro' ),
		'counter_title_4'				=> esc_html__( 'Awards wins', 'educollege-pro' ),
		'counter_number_4'				=> esc_html__( '150', 'educollege-pro' ),
		
		'counter_image'					=> get_template_directory_uri() . '/assets/uploads/counter.jpg',
		
		// testimonial
		'testimonial_section_enable'					=> true,
		'testimonial_section_link_enable'				=> false,
		'testimonial_content_type'						=> 'page',
		'testimonial_count'								=> 4,
		'testimonial_section_autoplay_slider_enable'	=> true,
		'testimonial_section_buttom_slider_enable'		=> true,
		'testimonial_btn_title'							=> esc_html__( 'Apply to educollege', 'educollege-pro' ),
		'testimonial_title'								=> esc_html__( 'Our testimonial', 'educollege-pro' ),
		'testimonial_link_title'						=> esc_html__( 'Quick Links', 'educollege-pro' ),
		'testimonial_link_content_type'					=> 'page',
		'testimonial_link_count'						=> 6,
		'testimonial_logo'								=> get_template_directory_uri() . '/assets/uploads/logo.png',
		'testimonial_image'								=> get_template_directory_uri() . '/assets/uploads/testimonial-bg.jpg',

		// client
		'client_section_enable'			=> true,
		'client_content_type'			=> 'page',
		'client_count'					=> 4,

	);

	$output = apply_filters( 'educollege_pro_default_theme_options', $educollege_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}