<?php
/**
 * Courses Section options
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */

// Add Courses section
$wp_customize->add_section( 'educollege_pro_course_section', array(
	'title'             => esc_html__( 'Courses','educollege-pro' ),
	'description'       => esc_html__( 'Courses Section options.', 'educollege-pro' ),
	'panel'             => 'educollege_pro_front_page_panel',
	'active_callback' 	=> 'educollege_pro_is_course_section_enable',
) );

// Courses content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[course_section_enable]', array(
	'default'			=> 	$options['course_section_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[course_section_enable]', array(
	'label'             => esc_html__( 'Course Section Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_course_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
) ) );

// course title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[course_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[course_title]', array(
	'label'           	=> esc_html__( 'Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_course_section',
	'active_callback' 	=> 'educollege_pro_is_course_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[course_title]', array(
		'selector'            => '#featured-courses .section-header h2',
		'settings'            => 'educollege_pro_theme_options[course_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_course_title_partial',
    ) );
}

// course sub title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[course_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[course_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_course_section',
	'active_callback' 	=> 'educollege_pro_is_course_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[course_sub_title]', array(
		'selector'            => '#featured-courses .section-header p',
		'settings'            => 'educollege_pro_theme_options[course_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_course_sub_title_partial',
    ) );
}

// course btn title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[course_read_more]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_read_more'],
) );

$wp_customize->add_control( 'educollege_pro_theme_options[course_read_more]', array(
	'label'           	=> esc_html__( 'Read More Label', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_course_section',
	'active_callback' 	=> 'educollege_pro_is_course_section_enable',
	'type'				=> 'text',
) );


// Event social icons number control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[course_count]', array(
	'default'          	=> $options['course_count'],
	'sanitize_callback' => 'educollege_pro_sanitize_number_range',
	'validate_callback' => 'educollege_pro_validate_course_count',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[course_count]', array(
	'label'             => esc_html__( 'Number of Courses', 'educollege-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'educollege-pro' ),
	'section'           => 'educollege_pro_course_section',
	'active_callback'   => 'educollege_pro_is_course_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Courses content type control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[course_content_type]', array(
	'default'          	=> $options['course_content_type'],
	'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[course_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'educollege-pro' ),
	'section'           => 'educollege_pro_course_section',
	'type'				=> 'select',
	'active_callback' 	=> 'educollege_pro_is_course_section_enable',
	'choices'			=> educollege_pro_popular_course_content_type(),
) );

for ( $i = 1; $i <= $options['course_count']; $i++ ) :

	// course pages drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[course_content_page_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[course_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_course_section',
		'choices'			=> educollege_pro_page_choices(),
		'active_callback'	=> 'educollege_pro_is_course_section_content_page_enable',
	) ) );	

	if ( class_exists( 'TP_Education' ) ) {
		// course pages drop down chooser control and setting
		$wp_customize->add_setting( 'educollege_pro_theme_options[course_content_course_' . $i . ']', array(
			'sanitize_callback' => 'educollege_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[course_content_course_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Course %d', 'educollege-pro' ), $i ),
			'section'           => 'educollege_pro_course_section',
			'choices'			=> educollege_pro_course_choices(),
			'active_callback'	=> 'educollege_pro_is_course_section_content_course_enable',
		) ) );		
	}

	
	// course posts drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[course_content_post_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[course_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_course_section',
		'choices'			=> educollege_pro_post_choices(),
		'active_callback'	=> 'educollege_pro_is_course_section_content_post_enable',
	) ) );

	// course hr setting and control
	$wp_customize->add_setting( 'educollege_pro_theme_options[course_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Educollege_Pro_Customize_Horizontal_Line( $wp_customize, 'educollege_pro_theme_options[course_hr_'. $i .']',
		array(
			'section'         => 'educollege_pro_course_section',
			'active_callback' => 'educollege_pro_is_course_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'educollege_pro_theme_options[course_content_course_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Educollege_Pro_Dropdown_Taxonomies_Control( $wp_customize,'educollege_pro_theme_options[course_content_course_category]', array(
	'label'             => esc_html__( 'Select Course Category', 'educollege-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'educollege-pro' ),
	'section'           => 'educollege_pro_course_section',
	'type'              => 'dropdown-taxonomies',
	'taxonomy'          => 'tp-course-category',
	'active_callback'	=> 'educollege_pro_is_course_section_content_course_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'educollege_pro_theme_options[course_content_category]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Educollege_Pro_Dropdown_Taxonomies_Control( $wp_customize,'educollege_pro_theme_options[course_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'educollege-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'educollege-pro' ),
	'section'           => 'educollege_pro_course_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'educollege_pro_is_course_section_content_category_enable'
) ) );

// course btn title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[course_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_btn_title'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'educollege_pro_theme_options[course_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_course_section',
	'active_callback' 	=> 'educollege_pro_is_course_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[course_btn_title]', array(
		'selector'            => '#featured-courses .view-all a',
		'settings'            => 'educollege_pro_theme_options[course_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_course_btn_title_partial',
    ) );
}


// course btn link setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[course_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[course_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_course_section',
	'active_callback' 	=> 'educollege_pro_is_course_section_enable',
	'type'				=> 'url',
) );
