<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage educollege Pro
 * @since educollege Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'educollege_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','educollege-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'educollege-pro' ),
	'panel'             => 'educollege_pro_front_page_panel',
	'active_callback' 	=> 'educollege_pro_is_featured_section_panel_enable',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_featured_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
) ) );

// featured title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[featured_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[featured_title]', array(
	'label'           	=> esc_html__( 'Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_featured_section',
	'active_callback' 	=> 'educollege_pro_is_featured_medical_design_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[featured_title]', array(
		'selector'            => '#medical-features .section-header h2',
		'settings'            => 'educollege_pro_theme_options[featured_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_featured_title_partial',
    ) );
}

// featured sub title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[featured_description]', array(
	'sanitize_callback' => 'sanitize_textarea_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[featured_description]', array(
	'label'           	=> esc_html__( 'Description', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_featured_section',
	'active_callback' 	=> 'educollege_pro_is_featured_medical_design_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[featured_description]', array(
		'selector'            => '#medical-features .section-header p',
		'settings'            => 'educollege_pro_theme_options[featured_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_featured_description_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'educollege_pro_sanitize_number_range',
	'validate_callback' => 'educollege_pro_validate_featured_count',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'educollege-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'educollege-pro' ),
	'section'           => 'educollege_pro_featured_section',
	'active_callback'   => 'educollege_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

// Featured content type control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'educollege-pro' ),
	'section'           => 'educollege_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'educollege_pro_is_featured_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'educollege-pro' ),
		'post' 		=> esc_html__( 'Post', 'educollege-pro' ),
		'category' 	=> esc_html__( 'Category', 'educollege-pro' ),
	),
) );


for ( $i = 1; $i <= $options['featured_count']; $i++ ) :

	$wp_customize->add_setting( 'educollege_pro_theme_options[featured_content_icon_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> $options['featured_content_icon'],
	) );
	
	$wp_customize->add_control( new Educollege_Pro_Icon_Picker( $wp_customize, 'educollege_pro_theme_options[featured_content_icon_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Icon %d', 'educollege-pro' ), $i ),
        'section'           => 'educollege_pro_featured_section',
        'active_callback'   => 'educollege_pro_is_featured_medical_design_enable',
    ) ) );

	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_featured_section',
		'choices'			=> educollege_pro_page_choices(),
		'active_callback'	=> 'educollege_pro_is_featured_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_featured_section',
		'choices'			=> educollege_pro_post_choices(),
		'active_callback'	=> 'educollege_pro_is_featured_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'educollege_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Educollege_Pro_Dropdown_Taxonomies_Control( $wp_customize,'educollege_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'educollege-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'educollege-pro' ),
	'section'           => 'educollege_pro_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'educollege_pro_is_featured_section_content_category_enable'
) ) );


