<?php
/**
 * Reason Section options
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */

// Add Reason section
$wp_customize->add_section( 'educollege_pro_reason_section', array(
	'title'             => esc_html__( 'Reason','educollege-pro' ),
	'description'       => esc_html__( 'Reason Section options.', 'educollege-pro' ),
	'panel'             => 'educollege_pro_front_page_panel',
	'active_callback' 	=> 'educollege_pro_is_reason_section_panel_enable',
) );

// Reason content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[reason_section_enable]', array(
	'default'			=> 	$options['reason_section_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[reason_section_enable]', array(
	'label'             => esc_html__( 'Reason Section Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_reason_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
) ) );

// Reason content type control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[reason_content_type]', array(
	'default'          	=> $options['reason_content_type'],
	'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[reason_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'educollege-pro' ),
	'section'           => 'educollege_pro_reason_section',
	'type'				=> 'select',
	'active_callback' 	=> 'educollege_pro_is_reason_section_enable',
	'choices'			=> array( 
		'custom' 	=> esc_html__( 'Custom', 'educollege-pro' ),
		'page' 		=> esc_html__( 'Page', 'educollege-pro' ),
		'post' 		=> esc_html__( 'Post', 'educollege-pro' ),
	),
) );


// about pages drop down chooser control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[reason_content_page]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_page',
) );

$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[reason_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'educollege-pro' ),
	'section'           => 'educollege_pro_reason_section',
	'choices'			=> educollege_pro_page_choices(),
	'active_callback'	=> 'educollege_pro_is_reason_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[reason_content_post]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_page',
) );

$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[reason_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'educollege-pro' ),
	'section'           => 'educollege_pro_reason_section',
	'choices'			=> educollege_pro_post_choices(),
	'active_callback'	=> 'educollege_pro_is_reason_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[reason_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['reason_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[reason_title]', array(
	'label'           	=> esc_html__( 'Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_reason_section',
	'active_callback' 	=> 'educollege_pro_is_reason_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[reason_title]', array(
		'selector'            => '#medical-reasons .entry-container header h2 a',
		'settings'            => 'educollege_pro_theme_options[reason_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_reason_title_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[reason_description]', array(
	'default'			=> $options['reason_description'],
	'sanitize_callback' => 'wp_kses_post',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[reason_description]', array(
	'label'           	=> esc_html__( 'Description', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_reason_section',
	'active_callback' 	=> 'educollege_pro_is_reason_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[reason_description]', array(
		'selector'            => '#about-us .entry-container .entry-content p',
		'settings'            => 'educollege_pro_theme_options[reason_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_reason_description_partial',
    ) );
}

// about image setting and control.
$wp_customize->add_setting( 'educollege_pro_theme_options[reason_image]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'educollege_pro_theme_options[reason_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'educollege-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'educollege-pro' ), 600, 600 ),
		'section'     		=> 'educollege_pro_reason_section',
		'active_callback'	=> 'educollege_pro_is_reason_section_content_custom_enable',
) ) );

// Contact social control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[reason_list]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'refresh',
    
) );

$wp_customize->add_control( new Educollege_Pro_Multi_Input_Custom_Control( $wp_customize, 'educollege_pro_theme_options[reason_list]', array(
    'label'             => esc_html__( 'Add List', 'educollege-pro' ),
    'button_text'       => esc_html__( 'Add List.', 'educollege-pro' ),
	'section'           => 'educollege_pro_reason_section',
    'active_callback' 	=> 'educollege_pro_is_reason_section_enable',
	'type'				=> 'multi-input',

)));