<?php
/**
 * service Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add service section
$wp_customize->add_section( 'educollege_pro_service_section', array(
	'title'             => esc_html__( 'Service','educollege-pro' ),
	'description'       => esc_html__( 'Service Section options.', 'educollege-pro' ),
	'panel'             => 'educollege_pro_front_page_panel',
	'active_callback' 	=> 'educollege_pro_is_service_section_panel_enable',
) );

// service content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_service_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
) ) );

// service title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_service_section',
	'active_callback' 	=> 'educollege_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[service_title]', array(
		'selector'            => '#our-services .section-header h2',
		'settings'            => 'educollege_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_service_title_partial',
    ) );
}

// service sub title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[service_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[service_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_service_section',
	'active_callback' 	=> 'educollege_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[service_sub_title]', array(
		'selector'            => '#our-services .section-header p',
		'settings'            => 'educollege_pro_theme_options[service_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_service_sub_title_partial',
    ) );
}

// service content type control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[service_column_layout]', array(
	'default'          	=> $options['service_column_layout'],
	'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[service_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'educollege-pro' ),
	'section'           => 'educollege_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'educollege_pro_is_service_section_enable',
	'choices'			=> array( 
		'col-3' 		=> esc_html__( '3 Column', 'educollege-pro' ),
		'col-4' 		=> esc_html__( '4 Column', 'educollege-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'educollege_pro_sanitize_number_range',
	'validate_callback' => 'educollege_pro_validate_service_count',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'educollege-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'educollege-pro' ),
	'section'           => 'educollege_pro_service_section',
	'active_callback'   => 'educollege_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// service content type control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'educollege-pro' ),
	'section'           => 'educollege_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'educollege_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'educollege-pro' ),
		'post' 		=> esc_html__( 'Post', 'educollege-pro' ),
		'category' 	=> esc_html__( 'Category', 'educollege-pro' ),
	),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :
	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_service_section',
		'choices'			=> educollege_pro_page_choices(),
		'active_callback'	=> 'educollege_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_service_section',
		'choices'			=> educollege_pro_post_choices(),
		'active_callback'	=> 'educollege_pro_is_service_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'educollege_pro_theme_options[service_content_icon_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> $options['service_content_icon_'.$i ],
    ) );

    $wp_customize->add_control( new Educollege_Pro_Icon_Picker( $wp_customize, 'educollege_pro_theme_options[service_content_icon_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Icon %d', 'educollege-pro' ), $i ),
        'section'           => 'educollege_pro_service_section',
        'active_callback'   => 'educollege_pro_is_service_section_enable',
    ) ) );

    $wp_customize->add_setting( 'educollege_pro_theme_options[service_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Educollege_Pro_Customize_Horizontal_Line( $wp_customize, 'educollege_pro_theme_options[service_hr_'. $i .']',
        array(
            'section'           => 'educollege_pro_service_section',
            'active_callback'   => 'educollege_pro_is_service_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'educollege_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Educollege_Pro_Dropdown_Taxonomies_Control( $wp_customize,'educollege_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'educollege-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'educollege-pro' ),
	'section'           => 'educollege_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'educollege_pro_is_service_section_content_category_enable'
) ) );