<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */

// Add team section
$wp_customize->add_section( 'educollege_pro_team_section', array(
	'title'             => esc_html__( 'Team','educollege-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'educollege-pro' ),
	'panel'             => 'educollege_pro_front_page_panel',
	'active_callback' 	=> 'educollege_pro_is_team_section_enable',
) );

// team content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_team_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'educollege_pro_theme_options[team_section_buttom_slider_enable]', array(
	'default'			=> 	$options['team_section_buttom_slider_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[team_section_buttom_slider_enable]', array(
	'label'             => esc_html__( 'Show Buttom Slider', 'educollege-pro' ),
	'section'           => 'educollege_pro_team_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
	'active_callback' 	=> 'educollege_pro_is_team_section_enable',
) ) );

$wp_customize->add_setting( 'educollege_pro_theme_options[team_section_autoplay_slider_enable]', array(
	'default'			=> 	$options['team_section_autoplay_slider_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[team_section_autoplay_slider_enable]', array(
	'label'             => esc_html__( 'Autoplay Slider Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_team_section',
	'active_callback' 	=> 'educollege_pro_is_team_section_enable',
	'on_off_label' 		=> educollege_pro_switch_options(),
) ) );

// team title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_team_section',
	'active_callback' 	=> 'educollege_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[team_title]', array(
		'selector'            => '#our-team .section-header h2',
		'settings'            => 'educollege_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_team_title_partial',
    ) );
}

// team sub title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[team_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[team_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_team_section',
	'active_callback' 	=> 'educollege_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[team_sub_title]', array(
		'selector'            => '#our-team .section-header p',
		'settings'            => 'educollege_pro_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_team_sub_title_partial',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'educollege_pro_sanitize_number_range',
	'validate_callback' => 'educollege_pro_validate_team_count',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of team', 'educollege-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'educollege-pro' ),
	'section'           => 'educollege_pro_team_section',
	'active_callback'   => 'educollege_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// team content type control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'educollege-pro' ),
	'section'           => 'educollege_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'educollege_pro_is_team_section_enable',
	'choices'			=> educollege_pro_popular_team_content_type(),
) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_team_section',
		'choices'			=> educollege_pro_page_choices(),
		'active_callback'	=> 'educollege_pro_is_team_section_content_page_enable',
	) ) );
	if ( class_exists( 'TP_Education' ) ) {
		// team pages drop down chooser control and setting
		$wp_customize->add_setting( 'educollege_pro_theme_options[team_content_team_' . $i . ']', array(
			'sanitize_callback' => 'educollege_pro_sanitize_page',
		) );

		$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[team_content_team_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Teacher %d', 'educollege-pro' ), $i ),
			'section'           => 'educollege_pro_team_section',
			'choices'			=> educollege_pro_team_choices(),
			'active_callback'	=> 'educollege_pro_is_team_section_content_team_enable',
		) ) );
	}
	

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_team_section',
		'choices'			=> educollege_pro_post_choices(),
		'active_callback'	=> 'educollege_pro_is_team_section_content_post_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'educollege_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Educollege_Pro_Customize_Horizontal_Line( $wp_customize, 'educollege_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'educollege_pro_team_section',
			'active_callback' => 'educollege_pro_is_team_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'educollege_pro_theme_options[team_content_team_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Educollege_Pro_Dropdown_Taxonomies_Control( $wp_customize,'educollege_pro_theme_options[team_content_team_category]', array(
	'label'             => esc_html__( 'Select Course Category', 'educollege-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'educollege-pro' ),
	'section'           => 'educollege_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'taxonomy'          => 'tp-team-category',
	'active_callback'	=> 'educollege_pro_is_team_section_content_team_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'educollege_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Educollege_Pro_Dropdown_Taxonomies_Control( $wp_customize,'educollege_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'educollege-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'educollege-pro' ),
	'section'           => 'educollege_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'educollege_pro_is_team_section_content_category_enable'
) ) );

