<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage educollege Pro
 * @since educollege Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'educollege_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','educollege-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'educollege-pro' ),
	'panel'             => 'educollege_pro_front_page_panel',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_enable',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_testimonial_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
) ) );


$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_section_buttom_slider_enable]', array(
	'default'			=> 	$options['testimonial_section_buttom_slider_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[testimonial_section_buttom_slider_enable]', array(
	'label'             => esc_html__( 'Show Buttom Slider', 'educollege-pro' ),
	'section'           => 'educollege_pro_testimonial_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_enable',
) ) );

$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_section_autoplay_slider_enable]', array(
	'default'			=> 	$options['testimonial_section_autoplay_slider_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[testimonial_section_autoplay_slider_enable]', array(
	'label'             => esc_html__( 'Autoplay Slider Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_testimonial_section',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_enable',
	'on_off_label' 		=> educollege_pro_switch_options(),
) ) );

// testimonial title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_testimonial_section',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[testimonial_title]', array(
		'selector'            => '.testimonial-title h2',
		'settings'            => 'educollege_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_testimonial_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'educollege_pro_sanitize_number_range',
	'validate_callback' => 'educollege_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'educollege-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'educollege-pro' ),
	'section'           => 'educollege_pro_testimonial_section',
	'active_callback'   => 'educollege_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'educollege-pro' ),
	'section'           => 'educollege_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_enable',
	'choices'			=> educollege_pro_testimonial_content_type(),
) );



for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_testimonial_section',
		'choices'			=> educollege_pro_page_choices(),
		'active_callback'	=> 'educollege_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_content_testimonial_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[testimonial_content_testimonial_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Testimonial %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_testimonial_section',
		'choices'			=> educollege_pro_testimonial_choices(),
		'active_callback'	=> 'educollege_pro_is_testimonial_section_content_testimonial_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_testimonial_section',
		'choices'			=> educollege_pro_post_choices(),
		'active_callback'	=> 'educollege_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'educollege-pro' ), $i ),
		'section'        	=> 'educollege_pro_testimonial_section',
		'active_callback' 	=> 'educollege_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'position %d', 'educollege-pro' ), $i ),
		'section'        	=> 'educollege_pro_testimonial_section',
		'active_callback' 	=> 'educollege_pro_is_testimonial_section_content_position_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'educollege-pro' ), $i ),
		'section'        	=> 'educollege_pro_testimonial_section',
		'active_callback' 	=> 'educollege_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'educollege_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'educollege-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'educollege-pro' ), 200, 200 ),
			'section'     		=> 'educollege_pro_testimonial_section',
			'active_callback'	=> 'educollege_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'educollege-pro' ), $i ),
		'section'        	=> 'educollege_pro_testimonial_section',
		'active_callback' 	=> 'educollege_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Educollege_Pro_Customize_Horizontal_Line( $wp_customize, 'educollege_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'educollege_pro_testimonial_section',
			'active_callback' => 'educollege_pro_is_testimonial_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// testimonial btn title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_testimonial_section',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[testimonial_btn_title]', array(
		'selector'            => '.application-content-wrapper a',
		'settings'            => 'educollege_pro_theme_options[testimonial_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_testimonial_btn_title_partial',
    ) );
}

// testimonial btn title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_testimonial_section',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_enable',
	'type'				=> 'url',
) );

$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_logo]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'educollege_pro_theme_options[testimonial_logo]',
	array(
	'label'       		=> esc_html__( 'Logo ', 'educollege-pro' ), 
	'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'educollege-pro' ), 288, 70 ),
	'section'     		=> 'educollege_pro_testimonial_section',
	'active_callback'	=> 'educollege_pro_is_testimonial_section_enable',
) ) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_section_link_enable]', array(
	'default'			=> 	$options['testimonial_section_link_enable'],
	'sanitize_callback' => 'educollege_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Educollege_Pro_Switch_Control( $wp_customize, 'educollege_pro_theme_options[testimonial_section_link_enable]', array(
	'label'             => esc_html__( 'Quick Links Enable', 'educollege-pro' ),
	'section'           => 'educollege_pro_testimonial_section',
	'on_off_label' 		=> educollege_pro_switch_options(),
	'active_callback'	=> 'educollege_pro_is_testimonial_section_link_enable',
) ) );


$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_image]', array(
	'sanitize_callback' => 'educollege_pro_sanitize_image',
	'default'			=> $options['testimonial_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'educollege_pro_theme_options[testimonial_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'educollege-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'educollege-pro' ), 675, 605 ),
		'section'     		=> 'educollege_pro_testimonial_section',
		'active_callback'	=> 'educollege_pro_is_testimonial_section_link_enable',
) ) );
// testimonial btn title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_link_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_link_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_link_title]', array(
	'label'           	=> esc_html__( 'Title', 'educollege-pro' ),
	'section'        	=> 'educollege_pro_testimonial_section',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_link_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'educollege_pro_theme_options[testimonial_link_title]', array(
		'selector'            => '.link-title h2',
		'settings'            => 'educollege_pro_theme_options[testimonial_link_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'educollege_pro_testimonial_link_title_partial',
    ) );
}

$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_link_content_type]', array(
	'default'          	=> $options['testimonial_link_content_type'],
	'sanitize_callback' => 'educollege_pro_sanitize_select',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_link_content_type]', array(
	'label'             => esc_html__( 'Links Content Type', 'educollege-pro' ),
	'section'           => 'educollege_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_link_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'educollege-pro' ),
		'post' 		=> esc_html__( 'Post', 'educollege-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'educollege-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_link_count]', array(
	'default'          	=> $options['testimonial_link_count'],
	'sanitize_callback' => 'educollege_pro_sanitize_number_range',
	'validate_callback' => 'educollege_pro_validate_testimonial_link_count',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_link_count]', array(
	'label'             => esc_html__( 'Number of Links', 'educollege-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'educollege-pro' ),
	'section'           => 'educollege_pro_testimonial_section',
	'active_callback'   => 'educollege_pro_is_testimonial_section_link_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['testimonial_link_count']; $i++ ) :

	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_link_content_page_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[testimonial_link_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_testimonial_section',
		'choices'			=> educollege_pro_page_choices(),
		'active_callback'	=> 'educollege_pro_is_testimonial_section_link_content_page_enable',
	) ) );
	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_link_content_post_' . $i . ']', array(
		'sanitize_callback' => 'educollege_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Educollege_Pro_Dropdown_Chooser( $wp_customize, 'educollege_pro_theme_options[testimonial_link_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'educollege-pro' ), $i ),
		'section'           => 'educollege_pro_testimonial_section',
		'choices'			=> educollege_pro_post_choices(),
		'active_callback'	=> 'educollege_pro_is_testimonial_section_link_content_post_enable',
	) ) );


	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_link_label_' . $i . ']', array(
	'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_link_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Link Label %d', 'educollege-pro' ), $i ),
		'section'        	=> 'educollege_pro_testimonial_section',
		'active_callback' 	=> 'educollege_pro_is_testimonial_section_link_content_custom_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_link_url_' . $i . ']', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_link_url_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Links Url %d', 'educollege-pro' ), $i ),		'section'        	=> 'educollege_pro_testimonial_section',
		'active_callback' 	=> 'educollege_pro_is_testimonial_section_link_content_custom_enable',
		'type'				=> 'url',
	) );

	$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Educollege_Pro_Customize_Horizontal_Line( $wp_customize, 'educollege_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'educollege_pro_testimonial_section',
			'active_callback' => 'educollege_pro_is_testimonial_section_link_enable',
			'type'			  => 'hr'
	) ) );
endfor;
