<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage educollege Pro
 * @since educollege Pro 1.0.0
 */
if ( ! function_exists( 'educollege_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since educollege Pro 1.0.0
    */
    function educollege_pro_add_testimonial_section() {
        $options = educollege_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'educollege_pro_section_status', true, 'testimonial_section_enable' );

        if( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design'){
            $testimonial_enable = false;
        }

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'educollege_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        educollege_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'educollege_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since educollege Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function educollege_pro_get_testimonial_section_details( $input ) {
        $options = educollege_pro_get_theme_options();

        // Content type.
        $testimonial_content_type  = $options['testimonial_content_type'];
        $testimonial_link_content_type  = $options['testimonial_link_content_type'];
        $testimonial_count = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 3;
        $testimonial_link_count = ! empty( $options['testimonial_link_count'] ) ? $options['testimonial_link_count'] : 6;
        
        $content['testimonial'] = array();
        $content['links']   = array();
        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();
                $position = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                        $position[] = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $position = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                        $position[] = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    $custom['title']        = ! empty( $options['testimonial_title_' . $i] ) ? $options['testimonial_title_' . $i] : '';
                    $custom['excerpt']      = ! empty( $options['testimonial_description_' . $i] ) ? $options['testimonial_description_' . $i] : '';
                    $custom['image']        = ! empty( $options['testimonial_image_' . $i] ) ? $options['testimonial_image_' . $i] : '';
                    $custom['url']          = ! empty( $options['testimonial_link_' . $i] ) ? $options['testimonial_link_' . $i] : '';
                    $custom['position']     = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';


                    // Push to the main array.
                    array_push( $content['testimonial'], $custom );
                }
            break;

            case 'tp-testimonial':
                if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }
                $testimonial_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_testimonial_' . $i] ) ) :
                        $testimonial_ids[] = $options['testimonial_content_testimonial_' . $i];
                    endif;
                }

               $args = array(
                    'post_type'         => 'tp-testimonial',
                    'post__in'          => ( array ) $testimonial_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;


            default:
            break;
        }

        if ( 'custom' !== $testimonial_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 0;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['position']  = ( $testimonial_content_type !== 'tp-testimonial'  && ! empty( $position[$i] ) ) ? $position[$i] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = educollege_pro_trim_content( 20 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id() ) : '';

                    // Push to the main array.
                    array_push( $content['testimonial'], $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }

        if ( $options['testimonial_section_link_enable'] == true && $options['home_layout'] == 'default-design') {
            switch ( $testimonial_link_content_type ) {
            
                case 'page':
                    $page_ids = array();

                    for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                        if ( ! empty( $options['testimonial_link_content_page_' . $i] ) ) :
                            $page_ids[] = $options['testimonial_link_content_page_' . $i];
                        endif;
                    }
                    
                    $link_args = array(
                        'post_type'         => 'page',
                        'post__in'          => ( array ) $page_ids,
                        'posts_per_page'    => absint( $testimonial_link_count ),
                        'orderby'           => 'post__in',
                        );                    
                break;

                case 'post':
                    $post_ids = array();

                    for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                        if ( ! empty( $options['testimonial_link_content_post_' . $i] ) ) :
                            $post_ids[] = $options['testimonial_link_content_post_' . $i];
                        endif;
                    }
                    
                    $link_args = array(
                        'post_type'         => 'post',
                        'post__in'          => ( array ) $post_ids,
                        'posts_per_page'    => absint( $testimonial_link_count ),
                        'orderby'           => 'post__in',
                        'ignore_sticky_posts'   => true,
                        );                    
                break;

                case 'custom':
                    for ( $i = 1; $i <= $testimonial_link_count; $i++ ) {
                        $custom_link['label']        = ! empty( $options['testimonial_link_label_' . $i] ) ? $options['testimonial_link_label_' . $i] : '';
                        $custom_link['url']          = ! empty( $options['testimonial_link_url_' . $i] ) ? $options['testimonial_link_url_' . $i] : '';

                        // Push to the main array.
                        array_push( $content['links'], $custom_link );
                    }
                break;

                default:
                break;
            }

            if ( 'custom' !== $testimonial_link_content_type ) {
                // Run The Loop.
                $query = new WP_Query( $link_args );
                $i = 0;
                if ( $query->have_posts() ) : 
                    while ( $query->have_posts() ) : $query->the_post();
                        $page_post['label']     = get_the_title();
                        $page_post['url']       = get_the_permalink();
                        // Push to the main array.
                        array_push( $content['links'], $page_post );
                        $i++;
                    endwhile;
                endif;
                wp_reset_postdata();
            }
        }
        
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'educollege_pro_filter_testimonial_section_details', 'educollege_pro_get_testimonial_section_details' );


if ( ! function_exists( 'educollege_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since educollege Pro 1.0.0
   *
   */
   function educollege_pro_render_testimonial_section( $content_details = array() ) {
        $options = educollege_pro_get_theme_options();
        $logo = empty( $options['testimonial_logo'] ) ? '' : $options['testimonial_logo'] ;
        $testimonial_autoplay = (bool) ($options['testimonial_section_autoplay_slider_enable']) ? 'true' : 'false';
        $testimonial_button_slider = (bool) ($options['testimonial_section_buttom_slider_enable']) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="testimonial-section" class="relative">
            <div class="<?php echo $options['testimonial_section_link_enable'] == true ? 'col-2' : 'col-1' ;?> clear">
                <div class="testimonial-wrapper">
                    <div class="testimomnial-content-wrapper">
                        <div class="section-header testimonial-title <?php echo $options['testimonial_section_link_enable'] == true ? '' : 'title-center' ; ?>">
                            <?php if ( ! empty( $options['testimonial_title'] ) ): ?>
                                <h2 class="section-title">
                                    <?php echo esc_html( $options['testimonial_title'] ) ; ?>
                                </h2>
                            <?php endif ?>
                            
                        </div><!-- .section-header -->

                        <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":<?php echo $testimonial_button_slider; ?>, "autoplay": <?php echo $testimonial_autoplay; ?>, "draggable": true, "fade": false }'>
                            <?php $i = 1; foreach ( $content_details['testimonial'] as $content ): ?>
                                <article>
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url( $content['image'] ) ; ?>" alt="client-0<?php echo esc_attr( $i ) ; ?>">
                                        <header class="entry-header">
                                            <h2 class="entry-title">    
                                                <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                                    <?php echo esc_html( $content['title'] ) ?>
                                                </a>
                                            </h2>
                                            <p class="position">
                                                <?php if ( $options['testimonial_content_type'] !== 'tp-testimonial' ):  
                                                    echo esc_html( $content['position'] );
                                                else:
                                                    educollege_pro_testimonial_designation( $content['id'] );
                                                endif; ?>
                                            </p>
                                        </header>
                                    </div><!-- .featured-image -->

                                    <div class="entry-content">
                                        <p>
                                            <?php echo wp_kses_post( $content['excerpt'] ) ; ?>
                                        </p>
                                    </div><!-- .entry-content -->
                                    <?php if ( $options['testimonial_content_type'] == 'tp-testimonial' ):
                                        tp_testimonial_rating( $content['id'] );
                                    endif ?>
                                </article>
                            <?php $i++; endforeach ?>
                        </div><!-- .testimonial-slider -->
                    </div><!-- .testimonial-content-wrapper -->

                    <div class="application-link">
                        <div class="application-content-wrapper">
                            <?php if ( ! empty( $logo ) ): ?>
                                <img src="<?php echo esc_url( $logo ) ; ?>" alt="logo">
                            <?php endif ?>
                            
                            <?php if ( ! empty( $options['testimonial_btn_title'] ) ): 
                                $url = ! empty( $options['testimonial_btn_url'] ) ? $options['testimonial_btn_url'] : '#';
                                ?>
                                <a href="<?php echo esc_url( $url ) ; ?>" class="btn">
                                    <?php echo esc_html(  $options['testimonial_btn_title'] ) ; ?>
                                </a>
                            <?php endif ?>
                            
                        </div><!-- .application-content-wrapper -->
                    </div><!-- .application-link -->
                </div><!-- .testimonial-wrapper -->
                <?php if ( $options['testimonial_section_link_enable'] == true && $options['home_layout'] == 'default-design'): 
                    $image   = empty( $options['testimonial_image'] ) ? '' : $options['testimonial_image'] ;
                    ?>
                    <div class="college-info-links" style="background-image:url('<?php echo esc_url( $image ) ; ?>');">
                        <div class="overlay"></div>
                        <div class="section-header link-title">
                                <?php if ( ! empty( $options['testimonial_link_title'] ) ): ?>
                                    <h2 class="section-title">
                                        <?php echo esc_html( $options['testimonial_link_title'] ) ; ?>
                                    </h2>
                                <?php endif ?>
                        </div><!-- .section-header -->
                        <ul>
                            <?php foreach( $content_details['links'] as $content ) : 

                                ?>
                                <li>
                                    <a href="<?php echo esc_url( ! empty( $content['url'] ) ? $content['url'] : '#' ) ; ?>">
                                        <?php echo esc_html( $content['label'] ) ; ?>
                                    </a>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    </div><!-- .college-info-links -->
                <?php endif ?>               
            </div><!-- .col-2 -->
        </div><!-- #testimonial-section -->
        
    <?php }
endif;
